@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
- *  Copyright (C) 2009, Michael "Svedrin" Ziegler <diese-addy@funzt-halt.net>
+ *  Copyright © 2009-2010, Michael "Svedrin" Ziegler <diese-addy@funzt-halt.net>
  *
  *  Mumble-Django is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,16 +14,22 @@
  *  GNU General Public License for more details.
 """
 
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns
 
 urlpatterns = patterns(
 	'mumble.views',
 	( r'djangousers',					'djangousers'		),
 	( r'(?P<server>\d+)/users',				'users' 		),
+	
 	( r'(?P<server>\d+)/(?P<userid>\d+)/texture.png',	'showTexture'		),
-	( r'(?P<server>\d+)/texture.png',			'showTexture'		),
+	
+	( r'murmur/tree/(?P<server>\d+)',			'mmng_tree'		),
+	( r'mumbleviewer/(?P<server>\d+).xml',			'mumbleviewer_tree_xml' ),
+	( r'mumbleviewer/(?P<server>\d+).json', 		'mumbleviewer_tree_json'),
+	
 	( r'mobile/(?P<server>\d+)',				'mobile_show'		),
 	( r'mobile/?$',						'mobile_mumbles'	),
+	
 	( r'(?P<server>\d+)',					'show'			),
 	( r'$',							'mumbles'		),
 )
