@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
- *  Copyright (C) 2009, Michael "Svedrin" Ziegler <diese-addy@funzt-halt.net>
+ *  Copyright © 2009-2010, Michael "Svedrin" Ziegler <diese-addy@funzt-halt.net>
  *
  *  Mumble-Django is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,3 +28,9 @@ class ObjectInfo( object ):
 	
 	def __unicode__( self ):
 		return unicode( self.__dict__ );
+	
+	def __contains__( self, name ):
+		return name in self.__dict__;
+	
+	def __getitem__( self, name ):
+		return self.__dict__[name];
